netapp_ontap.models.device_discovery_data API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.device_discovery_data`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DeviceDiscoveryDataSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DeviceDiscoveryData object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `capabilities: List[str] GET POST PATCH`

    The list of the capabilities of the discovered device.

  `chassis_id: str GET POST PATCH`

    Identifier associated with this specific discovered device, useful for locating the device in a data center.

  `ip_addresses: List[str] GET POST PATCH`

    The IP addresses on the discovered device.

    Example: ["192.168.100.24","192.168.100.26"]

  `name: str GET POST PATCH`

    Name of the discovered device.

    Example: ETY-R1S4-510Q13.datacenter.example.com

  `platform: str GET POST PATCH`

    Hardware platform of the discovered device.

    Example: 93180YC-EX

  `protocol: str GET POST PATCH`

    The protocol used to identify the discovered device. This can have a value of CDP or LLDP.

    Valid choices:

    - cdp
    - lldp
  `remaining_hold_time: Size GET POST PATCH`

    The number of seconds until the discovered device entry expires and is removed.

  `remote_port: str GET POST PATCH`

    The name of the remote port on the discovered device. The format is dependent on the reporting device.

    Example: FastEthernet0/12

  `system_name: str GET POST PATCH`

    Additional name used to identify a specific piece of equipment.

  `version: str GET POST PATCH`

    The version of the software running on the discovered device.

    Example: Cisco Nexus Operating System (NX-OS) Software, Version 8.1